**Example 1: 修改执行器**



Input: 

```
tccli tat ModifyInvoker --cli-unfold-argument  \
    --InvokerId ivk-b7s3qa5l \
    --Parameters {"var": "1"}
```

Output: 
```
{
    "Response": {
        "RequestId": "7f3acde8-196d-4be4-9fa7-359f79b026bc"
    }
}
```

